<?php
/**
 * @author ElisDN <mail@elisdn.ru>
 * @link http://www.elisdn.ru/blog/58/old-posts-promotion-on-twitter
 * @version 1.0
 */

namespace Cache;

class FileCache implements Cache
{
	private $file;
	private $data = [];

	public function __construct($file = 'cache.txt') {
		$this->file = $file;
	}

	public function get($key) {
		$this->load();
		return array_key_exists($key, $this->data) ? $this->data[$key] : null;
	}

	public function set($key, $value) {
		$this->load();
		$this->data[$key] = $value;
		$this->update();
	}

	public function has($key) {
		$this->load();
		return array_key_exists($key, $this->data);
	}

	public function remove($key) {
		$this->load();
		if (array_key_exists($key, $this->data)) {
			unset($this->data[$key]);
		}
		$this->update();
	}

	public function flush() {
		$this->data = [];
		$this->update();
	}

	private function load() {
		$this->data = $this->loadData();
	}

	private function update() {
		$this->updateData($this->data);
	}

	private function loadData() {
		$this->checkFile();
		return require($this->file);
	}

	private function checkFile() {
		if (!file_exists($this->file)) {
			$this->updateData([]);
		}
	}

	private function updateData($data) {
		file_put_contents($this->file, '<?php' . PHP_EOL . 'return ' . var_export($data, true) . ';');
	}
}